@@ -34,7 +34,9 @@ from vdsm.common import hostdev
 from vdsm.common import supervdsm
 from vdsm.config import config
 from vdsm.host import rngsources
+from vdsm.storage import exception as se
 from vdsm.storage import hba
+from vdsm.storage import managedvolume
 from vdsm import cpuinfo
 from vdsm import host
 from vdsm import hugepages
@@ -138,6 +140,14 @@ def get():
     caps['hugepages'] = hugepages.supported()
     caps['kernelFeatures'] = osinfo.kernel_features()
     caps['vncEncrypted'] = _isVncEncrypted()
+
+    try:
+        caps["connector_info"] = managedvolume.connector_info()
+    except se.ManagedVolumeNotSupported as e:
+        logging.info("managedvolume not supported: %s", e)
+    except se.ManagedVolumeHelperFailed as e:
+        logging.exception("Error getting managedvolume connector info: %s", e)
+
     return caps
 
 
