@@ -17,12 +17,15 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
+from __future__ import division
 import logging
 import sys
 import time
 
 import six
+from six.moves import range
 
 """
 shared utilities and common code for the virt package
@@ -110,6 +113,7 @@ class ExpiringCache(object):
 
             return bool(self._items)
 
+    # pylint: disable=nonzero-method
     def __nonzero__(self):  # TODO: drop when py2 is no longer needed
         return self.__bool__()
 
@@ -189,7 +193,7 @@ class DynamicBoundedSemaphore(object):
     def bound(self, value):
         """ Dynamically updates semaphore bound.
 
-        When the the specified value is larger than the previous bound,
+        When the specified value is larger than the previous bound,
         it releases the semaphore the required number of times (and possibly
         wakes that number of waiting threads).
 
@@ -215,10 +219,6 @@ class DynamicBoundedSemaphore(object):
                 self.release()
 
 
-def is_kvm(vm_custom):
-    return 'containerType' not in vm_custom
-
-
 def has_xml_configuration(params):
     if 'xml' in params:
         # fresh startup from Engine >= 4.2
