@@ -18,6 +18,9 @@
 # Refer to the README and COPYING files for full details of the license
 #
 
+from __future__ import absolute_import
+from __future__ import division
+
 import subprocess
 from testlib import VdsmTestCase as TestCaseBase
 from testlib import namedTemporaryDir
